from enum import Enum


class Characteristic(Enum):
    STANDARD = "Standard"
    ONE_SABER = "OneSaber"
    NO_ARROWS = "NoArrows"
    _90_DEGREE = "90Degree"
    _360_DEGREE = "360Degree"
    LIGHTSHOW = "Lightshow"
    LAWLESS = "Lawless"
